==> estateplat-common-1.2.4-20210610.031722-788-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxSfxm.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version V1.0, 2021/4/8
 * @description 收费项目
 */
@Table(name = "GX_WW_SQXX_SFXM")
public class GxWwSqxxSfxm {
    @Id
    private String sfxmid;
    private String bz;//标准
    private String dw;//单位
    private String dwmc;//单位名称
    private String sfxm;//收费项目
    private String sfxmmc;//收费项目名称
    private Integer sl;//数量
    private Double yjje;//金额
    private String sfxxid;

    public String getSfxmid() {
        return sfxmid;
    }

    public void setSfxmid(String sfxmid) {
        this.sfxmid = sfxmid;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getDwmc() {
        return dwmc;
    }

    public void setDwmc(String dwmc) {
        this.dwmc = dwmc;
    }

    public String getSfxm() {
        return sfxm;
    }

    public void setSfxm(String sfxm) {
        this.sfxm = sfxm;
    }

    public String getSfxmmc() {
        return sfxmmc;
    }

    public void setSfxmmc(String sfxmmc) {
        this.sfxmmc = sfxmmc;
    }

    public Integer getSl() {
        return sl;
    }

    public void setSl(Integer sl) {
        this.sl = sl;
    }

    public Double getYjje() {
        return yjje;
    }

    public void setYjje(Double yjje) {
        this.yjje = yjje;
    }

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }
}

==> estateplat-common-1.2.4-20221008.084808-1099-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxSfxm.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version V1.0, 2021/4/8
 * @description 收费项目
 */
@Table(name = "GX_WW_SQXX_SFXM")
public class GxWwSqxxSfxm {
    @Id
    private String sfxmid;
    private String bz;//标准
    private String dw;//单位
    private String dwmc;//单位名称
    private String sfxm;//收费项目
    private String sfxmmc;//收费项目名称
    private Integer sl;//数量
    private Double yjje;//金额
    private String sfxxid;
    private String jfzt;//缴费状态
    private String sfbl;//收费比例

    public String getSfxmid() {
        return sfxmid;
    }

    public void setSfxmid(String sfxmid) {
        this.sfxmid = sfxmid;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getDwmc() {
        return dwmc;
    }

    public void setDwmc(String dwmc) {
        this.dwmc = dwmc;
    }

    public String getSfxm() {
        return sfxm;
    }

    public void setSfxm(String sfxm) {
        this.sfxm = sfxm;
    }

    public String getSfxmmc() {
        return sfxmmc;
    }

    public void setSfxmmc(String sfxmmc) {
        this.sfxmmc = sfxmmc;
    }

    public Integer getSl() {
        return sl;
    }

    public void setSl(Integer sl) {
        this.sl = sl;
    }

    public Double getYjje() {
        return yjje;
    }

    public void setYjje(Double yjje) {
        this.yjje = yjje;
    }

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getJfzt() {
        return jfzt;
    }

    public void setJfzt(String jfzt) {
        this.jfzt = jfzt;
    }

    public String getSfbl() {
        return sfbl;
    }

    public void setSfbl(String sfbl) {
        this.sfbl = sfbl;
    }
}
